# Thercy

[![PyPI Downloads](https://img.shields.io/pypi/dm/thercy.svg?label=PyPI%20downloads)](
https://pypi.org/project/thercy/)

Thercy is a thermodynamic cycle solver package. It simplifies the modeling and analysis of thermodynamic cycles, allowing to efficiently simulate and optimize sophisticated thermal systems.

It provides:

- advanced Rankine cycle builder
- representation of thermodynamic states
- representation of cycles and connected graphs
- thermodynamic diagrams
